# Standard version scheme

-----

See the documentation for [versioning](../../version.md#updating).

#### Configuration

The version scheme plugin name is `standard`.

=== ":octicons-file-code-16: pyproject.toml"

    ```toml
    [tool.hatch.version]
    scheme = "standard"
    ```

=== ":octicons-file-code-16: hatch.toml"

    ```toml
    [version]
    scheme = "standard"
    ```

## Options

There are no options available currently.
